@@ -276,7 +276,7 @@ class FeaturesAssembler(AbstractAssembler):
                                                       local_root_directory=self.local_root_directory)
         return shortcut_df
 
-    def preprocessReturns(self, lookback_window, ts_fresh_indices = ['SPXT'], add_signal_predictor = False):
+    def preprocessReturns(self, lookback_window, ts_fresh_indices = ['SPXT'], add_signal_predictor = False , add_ts_features_index = False):
 
         df = self.dbx.local_overwrite_and_load_pickle( folder='', subfolder='', returns_pkl_file_name=self.returns_pkl_file_name, local_root_directory = self.local_root_directory)
         df['Date'] = pd.to_datetime(df['Date'])
@@ -299,15 +299,16 @@ class FeaturesAssembler(AbstractAssembler):
 
         print('Max ts fresh features date before advanced ' + str(max(ts_features.index)))
         print('Min ts fresh features date before advanced ' + str(min(ts_features.index)))
+        if add_ts_features_index:
+            advanced_ts_features = buildAdvancedPriceFeatures(quotes_df=ts_features[ts_fresh_indices],lookback_window=lookback_window, rolling_direction=self.rolling_direction)
+            print('Advanced ts fresh features size')
+            print(ts_features.shape)
+            print('Max ts fresh features date ' + str(max(advanced_ts_features.index)))
+            print('Min ts fresh features date ' + str(min(advanced_ts_features.index)))
 
-        advanced_ts_features = buildAdvancedPriceFeatures(quotes_df=ts_features[ts_fresh_indices],lookback_window=lookback_window, rolling_direction=self.rolling_direction)
-        print('Advanced ts fresh features size')
-        print(ts_features.shape)
-        print('Max ts fresh features date ' + str(max(advanced_ts_features.index)))
-        print('Min ts fresh features date ' + str(min(advanced_ts_features.index)))
+            print('Advanced ts fresh features size')
+            df = pd.merge(df, advanced_ts_features, how='left', left_index=True, right_index=True)
 
-        print('Advanced ts fresh features size')
-        df = pd.merge(df, advanced_ts_features, how='left', left_index=True, right_index=True)
         print('Max return date after filtering' + str(max(df.index)))
         print('Min return date after filtering' + str(min(df.index)))
 
