@@ -142,10 +142,10 @@ def volume_weighted_high_low_vol(data = None, vol_threshold = 0.8, up_trend_thre
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
     data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_high'].map(high)
-    data['aggregated_low'] =  data['aggregated_low'].map(low)
+    data['aggregated_high'] =  data['aggregated_indice'].map(high)
+    data['aggregated_low'] =  data['aggregated_indice'].map(low)
 
-    data = data[::,-lag]
+    data = data[::-lag]
     data = data.iloc[::-1]
 
     data['hl'] = (data['aggregated_high'] - data['aggregated_low'])/data['aggregated_low']
